==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/usecase/impl/GeneralizationSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.usecase.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.usecase.Generalization;
import io.ciera.tool.sql.ooaofooa.usecase.GeneralizationSet;
import io.ciera.tool.sql.ooaofooa.usecase.UseCaseAssociationSet;
import io.ciera.tool.sql.ooaofooa.usecase.impl.UseCaseAssociationSetImpl;

import java.util.Arrays;
import java.util.List;


public class GeneralizationSetImpl extends InstanceSet<GeneralizationSet,Generalization> implements GeneralizationSet {

    // attributes
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( Generalization generalization : this ) generalization.setDescrip( m_Descrip );
    }
    @Override
    public void setAssoc_ID( UniqueId ref_Assoc_ID ) throws XtumlException {
        for ( Generalization generalization : this ) generalization.setAssoc_ID( ref_Assoc_ID );
    }


    // selections
    @Override
    public UseCaseAssociationSet R1210_is_a_UseCaseAssociation() throws XtumlException {
        UseCaseAssociationSet usecaseassociationset = new UseCaseAssociationSetImpl();
        for ( Generalization generalization : this ) usecaseassociationset.add( generalization.R1210_is_a_UseCaseAssociation() );
        return usecaseassociationset;
    }


    @Override
    public Generalization nullElement() {
        return GeneralizationImpl.EMPTY_GENERALIZATION;
    }

    @Override
    public GeneralizationSet emptySet() {
      return new GeneralizationSetImpl();
    }

    @Override
    public GeneralizationSet value() {
        return this;
    }

    @Override
    public List<Generalization> elements() {
        return Arrays.asList(toArray(new Generalization[0]));
    }

}

==> tool-sql-2.2.0-sources.jar: io/ciera/tool/sql/ooaofooa/usecase/impl/GeneralizationSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.usecase.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.usecase.Generalization;
import io.ciera.tool.sql.ooaofooa.usecase.GeneralizationSet;
import io.ciera.tool.sql.ooaofooa.usecase.UseCaseAssociationSet;
import io.ciera.tool.sql.ooaofooa.usecase.impl.UseCaseAssociationSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class GeneralizationSetImpl extends InstanceSet<GeneralizationSet,Generalization> implements GeneralizationSet {

    public GeneralizationSetImpl() {
    }

    public GeneralizationSetImpl(Comparator<? super Generalization> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( Generalization generalization : this ) generalization.setDescrip( m_Descrip );
    }
    @Override
    public void setAssoc_ID( UniqueId ref_Assoc_ID ) throws XtumlException {
        for ( Generalization generalization : this ) generalization.setAssoc_ID( ref_Assoc_ID );
    }


    // selections
    @Override
    public UseCaseAssociationSet R1210_is_a_UseCaseAssociation() throws XtumlException {
        UseCaseAssociationSet usecaseassociationset = new UseCaseAssociationSetImpl();
        for ( Generalization generalization : this ) usecaseassociationset.add( generalization.R1210_is_a_UseCaseAssociation() );
        return usecaseassociationset;
    }


    @Override
    public Generalization nullElement() {
        return GeneralizationImpl.EMPTY_GENERALIZATION;
    }

    @Override
    public GeneralizationSet emptySet() {
      return new GeneralizationSetImpl();
    }

    @Override
    public GeneralizationSet emptySet(Comparator<? super Generalization> comp) {
      return new GeneralizationSetImpl(comp);
    }

    @Override
    public GeneralizationSet value() {
        return this;
    }

    @Override
    public List<Generalization> elements() {
        return Arrays.asList(toArray(new Generalization[0]));
    }

}
